# ------------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# ------------------------------------------------------------------------------

from mssqlctl.cli.core.clients.cli_client import CliClient
from mssqlctl.cli.core.profile import MSSQLProfile


def beget(_):
    """Client factory for user's authentication profile."""
    return ProfileClientMixin()


class ProfileClientMixin(CliClient):
    """
    User profile client.
    """

    def __init__(self):
        super(ProfileClientMixin, self).__init__(False, False)

    def set_profile(self, token, controller_endpoint, controller_username, cluster_name, accept_eula):
        MSSQLProfile(auth_token=token,
                     controller_endpoint=controller_endpoint,
                     controller_username=controller_username,
                     cluster_name=cluster_name,
                     accept_eula=accept_eula)

    def list_profile(self):
        return MSSQLProfile().list()

    def controller_endpoint(self):
        return MSSQLProfile().controller_endpoint

    def accept_eula(self):
        return MSSQLProfile().accept_eula

    def cluster_name(self):
        return MSSQLProfile().cluster_name

    def login(self, controller_endpoint, controller_username, controller_password, cluster_name, accept_eula):

        token = self.apis.controller.acquire_token_with_basic(controller_endpoint, controller_username, controller_password)

        # -- persist token and endpoint into the profile --
        self.set_profile(token, controller_endpoint, controller_username, cluster_name, accept_eula)

    def logout(self):
        profile = MSSQLProfile()
        username = profile.get_current_account_user()

        if username:
            profile.logout(username)
