# ------------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# ------------------------------------------------------------------------------

from knack.help_files import helps
from mssqlctl.cli.commands.cluster import _

# pylint: disable=line-too-long
helps['login'] = """
    type: command
    short-summary: {short}
    long-summary: {long}
    examples:
        - name: {ex1}
          text: >
            azdata login
        - name: {ex2}
          text: >
            azdata login --cluster-name ClusterName --controller-user johndoe@contoso.com 
            --controller-endpoint https://<ip>:30080 --accept-eula yes
        - name: {ex3}
          text: >
            azdata login -n ClusterName
""".format(
    short=_('Log in to the cluster\'s controller endpoint.'),
    long=_('When your cluster is deployed, it will list the controller endpoint during deployment, which you should '
           'use to login.  If you do not know the controller endpoint, you may login by having your cluster\'s kube '
           'config on your system in the default location of <user home>/.kube/config or use the KUBECONFIG env var, '
           'i.e. export KUBECONFIG=path/to/.kube/config.'),
    ex1=_('Log in interactively. '
          'Cluster name will always be prompted for if not specified as an argument. '
          'If you have the CONTROLLER_USERNAME, CONTROLLER_PASSWORD, and ACCEPT_EULA env variables set on your system, '
          'these will not be prompted for. If you have the kube config on your system or are using the '
          'KUBECONFIG env var to specify the path to the config, the interactive experience will first try to use the '
          'config and then prompt you if the config fails.'),
    ex2=_('Log in (non-interactively). '
          'Log in with cluster name, controller user name, controller endpoint, and EULA acceptance set as arguments. '
          'The environment variable CONTROLLER_PASSWORD must be set.  If you do not want to specify the controller '
          'endpoint, please have the kube config on your machine in the default location of <user home>/.kube/config '
          'or use the KUBECONFIG env var, i.e. export KUBECONFIG=path/to/.kube/config.'),
    ex3=_('Log in with kube config on machine, and env var set for CONTROLLER_USERNAME, CONTROLLER_PASSWORD, and '
          'ACCEPT_EULA.')
)

helps['logout'] = """
    type: command
    short-summary: {short}
    examples:
        - name: {ex1}
          text: >
            azdata logout
""".format(
    short=_('Log out of cluster.'),
    ex1=_('Log out this user.')
)
