# ------------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# ------------------------------------------------------------------------------

import os
import pymssql
from mssqlctl.cli.commands.app.app_swagger import AppSwagger
from mssqlctl.cli.commands.app.exceptions import (
    AppError,
    IllegalAppStateError
)
from mssqlctl.cli.commands.app.util import cmd_inputs_to_dict
from mssqlctl.cli.core.clients.cli_client import CliClient
from mssqlctl.cli.core.exceptions import ApiError
from mssqlcli.config import config_location
from mssqlcli.mssqlclioptionsparser import create_parser
from mssqlcli.main import run_cli_with, display_version_message, configure_and_update_options
from mssqlcli.config import get_config
from collections import OrderedDict
from mssqlctl.cli.core.exceptions import CliError
from mssqlctl.cli.core import Configuration
from configobj import ConfigObj
from os.path import expanduser, isfile


def beget(_):
    """Client factory"""
    return SqlClientMixin(check_auth=True, check_eula=True)


class SqlClientMixin(CliClient):
    def __init__(self, check_auth=True, check_eula=True):
        super(SqlClientMixin, self).__init__(check_auth=check_auth, check_eula=check_eula)

        # Add config file option value
        config_path = self.get_config_path()

        if not isfile(config_path):
            # The CLI has it's own configuration file.  With the integration it made sense to have a separate
            # configuration so users can configure them differently if they want.  Since the file is identical
            # they can also copy over the file to make them the same.  This imports the CLI code and uses that
            # to create the default config file then edits it to not spew info output to the console.
            #
            get_config(config_path)
            cfg = ConfigObj(expanduser(config_path), interpolation=False, encoding='utf-8')
            cfg.filename = expanduser(config_path)
            cfg["main"]["log_level"] = "NONE"
            cfg.write()

    def get_config_path(self):
        profile_path = os.path.expanduser(Configuration().CLI_CONFIG_DIR)
        config_path = os.path.join(profile_path, "mssql-cli.config")
        return config_path

    def get_cluster_endpoint(self, endpoint_name=None):
        try:
            endpoint = self.apis.controller.get_endpoints(endpoint_name)['endpoint']
        except Exception as e:
            raise CliError(e)

        return endpoint

    def run_shell(self, endpoint, username, password):
        args = [
            "-S", endpoint,
            "-U", username,
            "-P", password
        ]

        os.environ["MSSQL_CLI_TELEMETRY_OPTOUT"] = "1"
        mssqlcli_options_parser = create_parser()
        mssqlcli_options = mssqlcli_options_parser.parse_args(args)

        config_path = self.get_config_path()
        mssqlcli_options.mssqlclirc_file = config_path
        run_cli_with(mssqlcli_options)

        return

    def run_query(self, endpoint, username, password, database, query):
        connection_info = endpoint.split(',')
        if len(connection_info) == 1:
            host = connection_info[0]
            port = 1433
        else:
            host = connection_info[0]
            port = connection_info[1]
        conn = pymssql.connect(host=host, port=port,user=username,password=password,database=database)
        cursor = conn.cursor(as_dict=True)
        cursor.execute(query)
        result = cursor.fetchall()
        conn.close()
        return result
