# ------------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# ------------------------------------------------------------------------------

import os
from mssqlctl.cli.core.util import raise_command_error
from knack.prompting import (prompt_pass, NoTTYException)


def _get_sql_username():
    # Note for now the SQL username is hard coded to 'sa'.
    return "sa"

def _get_sql_password(client):
    # Note for now if the environment variable isn't set prompt for the password..
    if not os.getenv('MSSQL_SA_PASSWORD'):
        if not os.getenv('CONTROLLER_PASSWORD'):
            try:
                client.stdout(
                    "The SQL Server sa or controller password is needed.  It can be set for the session by setting the environment variable MSSQL_SA_PASSWORD.")
                client.stdout("If SQL Server sa password is not set then CONTROLLER_PASSWORD is used.")
                password = prompt_pass('Enter SQL Server sa Password: ')
            except NoTTYException:
                raise NoTTYException('Missing MSSQL_SA_PASSWORD or CONTROLLER_PASSWORD environment variable in non-interactive environment.')
        else:
            password = os.environ['CONTROLLER_PASSWORD']
    else:
        password = os.environ['MSSQL_SA_PASSWORD']

    return password

def _get_login_data(client):
    endpoint = client.get_cluster_endpoint("sql-server-master")

    # Eventually a single user/password should be used and gotten from the profile.  For now use the hard coded user.
    # profile = MSSQLProfile().list()
    # username = profile["controllerUserName"]
    username = _get_sql_username()
    password = _get_sql_password(client)

    return endpoint, username, password

def sql_shell(client):
    try:
        endpoint, username, password = _get_login_data(client)
        result = client.run_shell(endpoint, username, password)
    except Exception as ex:
        raise_command_error(ex)

def sql_query(client, database, query):
    try:
        endpoint, username, password = _get_login_data(client)
        result = client.run_query(endpoint, username, password, database, query)
        return result
    except Exception as ex:
        raise_command_error(ex)

